@@ -1,3 +1,3 @@
-from .arknights import Arknights  # noqa: F401
+from .ak import Arknights  # noqa: F401
 from .cgi import AkCall  # noqa: F401
 from .exception import PostException  # noqa: F401
